OSSP CVS Repository

ossp - Difference in ossp-pkg/petidomo/unsubscribe.c versions 1.18 and 1.19
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [History

ossp-pkg/petidomo/unsubscribe.c 1.18 -> 1.19

--- unsubscribe.c        2001/01/19 14:56:33     1.18
+++ unsubscribe.c        2001/01/20 13:52:41     1.19
@@ -1,6 +1,6 @@
 /*
    $Source: /v/ossp/cvs/ossp-pkg/petidomo/unsubscribe.c,v $
-   $Revision: 1.18 $
+   $Revision: 1.19 $
 
    Copyright (C) 2000 by CyberSolutions GmbH, Germany.
 
@@ -89,9 +89,9 @@
                 fprintf(fh, "\n");
                 buffer = text_easy_sprintf("You tried to unsubscribe the address \"%s\" from a mailing list. "   \
                                            "Unfortunately, your request could not be processed, because "    \
-                                           "you didn't specify a valid mailing list name from which the "      \
+                                           "you did not specify a valid mailing list name from which the "      \
                                            "address should be unsubscribed. You may use the command INDEX " \
-                                           "to receive an overview over the available mailing lists. Also, " \
+                                           "to receive an overview of the available mailing lists. Also, " \
                                            "use the command HELP to verify that you got the command syntax " \
                                            "right.", address);
                 text_wordwrap(buffer, 70);
@@ -215,7 +215,7 @@
         if (isValidAdminPassword(getPassword(), listname) == FALSE &&
             ListConfig->subtype == SUBSCRIPTION_ACKED && !g_is_approved)
             {
-            /* Require confirmation. */
+            /* Require approval. */
 
             char* command;
             char* cookie;
@@ -226,25 +226,28 @@
             command = text_easy_sprintf("unsubscribe %s %s", address, listname);
             cookie  = queue_command(MailStruct, command);
 
             /* Send request for confirmation to the user. */
 
             fh = vOpenMailer(envelope, address, NULL);
             if (fh != NULL)
                 {
                 fprintf(fh, "From: petidomo-approve@%s (Petidomo Mailing List Server)\n", ListConfig->fqdn);
                 fprintf(fh, "To: %s\n", address);
-                fprintf(fh, "Subject: Petidomo: CONFIRM %s@%s: Request from \"%s\"\n", listname, ListConfig->fqdn, originator);
+                if (strcasecmp(address, originator) == 0)
+                    fprintf(fh, "Subject: Petidomo: APPROVE %s@%s: Your request \"subscribe %s\"\n", listname, ListConfig->fqdn, listname);
+                else
+                    fprintf(fh, "Subject: Petidomo: APPROVE %s@%s: Request \"subscribe %s\" from \"%s\"\n", listname, ListConfig->fqdn, listname, originator);
                 fprintf(fh, "Precedence: junk\n");
                 fprintf(fh, "Sender: %s\n", envelope);
                 fprintf(fh, "\n");
                 if (strcasecmp(address, originator) == 0)
                     buffer = text_easy_sprintf("You requested that the address \"%s\" should be unsubscribed from " \
-                                               "the mailing list \"%s\". This will not happen unless you confirm the " \
+                                               "the mailing list \"%s\". This will not happen unless you approve the " \
                                                "request by replying to this mail and citing the string",
                                                originator, address, listname);
                 else
                     buffer = text_easy_sprintf("Per request from \"%s\", the address \"%s\" should be unsubscribed from " \
-                                               "the mailing list \"%s\". This will not happen unless you confirm the " \
+                                               "the mailing list \"%s\". This will not happen unless you approve the " \
                                                "request by replying to this mail and citing the string",
                                                originator, address, listname);
                 text_wordwrap(buffer, 70);
@@ -259,7 +262,7 @@
                 return -1;
                 }
 
             /* If the request for confirmation has been sent to an
                address different to that of the originator, notify him
                what happened. */
 
@@ -276,8 +279,9 @@
                     fprintf(fh, "Precedence: junk\n");
                     fprintf(fh, "Sender: %s\n", envelope);
                     fprintf(fh, "\n");
-                    fprintf(fh, "Unsubscribing the address will need confirmation. Such a\n");
-                    fprintf(fh, "request has been sent to the address already, so don't move!\n");
+                    fprintf(fh, "Unsubscribing the address \"%s\" from the list \"%s\"\n", address, listname);
+                    fprintf(fh, "requires additional approval by \"%s\". A request\n", address);
+            fprintf(fh, "has been sent to this address. We are now awaiting the approval.\n");
                     CloseMailer(fh);
                     }
                 else
@@ -226,25 +226,28 @@
             cookie  = queue_command(MailStruct, command);
 
-            /* Send request for confirmation to the user. */
+            /* Send request for approval to the user. */
 
             fh = vOpenMailer(envelope, address, NULL);
@@ -259,7 +262,7 @@
                 }
 
-            /* If the request for confirmation has been sent to an
+            /* If the request for approval has been sent to an
                address different to that of the originator, notify him
                what happened. */

CVSTrac 2.0.1